//
//  BytesSizeTransformer.m
//  pithos-macos
//
// Copyright 2011 GRNET S.A. All rights reserved.
//
// Redistribution and use in source and binary forms, with or
// without modification, are permitted provided that the following
// conditions are met:
// 
//   1. Redistributions of source code must retain the above
//      copyright notice, this list of conditions and the following
//      disclaimer.
// 
//   2. Redistributions in binary form must reproduce the above
//      copyright notice, this list of conditions and the following
//      disclaimer in the documentation and/or other materials
//      provided with the distribution.
// 
// THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
// OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
// USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
// AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
// ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// 
// The views and conclusions contained in the software and
// documentation are those of the authors and should not be
// interpreted as representing official policies, either expressed
// or implied, of GRNET S.A.

#import "BytesSizeTransformer.h"

@implementation BytesSizeTransformer

+ (Class)transformedValueClass {
	return [NSString class];
}

+ (BOOL)allowsReverseTransformation {
	return NO;
}

- (id)transformedValue:(id)value {
    if (value == nil)
		return nil;
    double bytes = [value unsignedIntegerValue] + 0.0;
    if (bytes <= 999) {
        return [NSString stringWithFormat:@"%d B", (int)bytes];
    } else if (bytes <= 999000) {
        return [NSString stringWithFormat:@"%d KB", (int)ceil(bytes / 1000)];
    } else if (bytes <= 999900000) {
        double megabytes = floor(bytes / 1000000);
        double hundredkilobytes = ceil((bytes - megabytes * 1000000) / 100000);
        if (hundredkilobytes == 10) {
            megabytes++;
            hundredkilobytes = 0;
        }
        if (hundredkilobytes == 0) {
            return [NSString stringWithFormat:@"%d MB", (int)megabytes];
        } else {
            return [NSString stringWithFormat:@"%d.%d MB", (int)megabytes, (int)hundredkilobytes];
        }
    } else {
        double gigabytes = floor(bytes / 1000000000);
        double hundredmegabytes = ceil((bytes - gigabytes * 1000000000) / 100000000);
        if (hundredmegabytes == 10) {
            gigabytes++;
            hundredmegabytes = 0;
        }
        if (hundredmegabytes == 0) {
            return [NSString stringWithFormat:@"%d GB", (int)gigabytes];
        } else {
            return [NSString stringWithFormat:@"%d.%d GB", (int)gigabytes, (int)hundredmegabytes];
        }
    }
}

+ (void)initialize {
    [[self class] setValueTransformer:[self new] forName:@"BytesSizeTransformer"];
}

@end
